window.Gleam.initSearch([{"doc":"recursive","title":"recursive","content":"[![Package Version](https://img.shields.io/hexpm/v/recursive)](https://hex.pm/packages/recursive)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/recursive/)\n\n# recursive\n\nThis library provides user/developer friendly Fixed-point combinator functions.\n\n```sh\ngleam add recursive\n```\n\n## Recursive block\n\n```gleam\nimport gleam/io\nimport recursive\n\npub fn main() {\n   // Factorial\n   io.debug({\n    use it, f &lt;- recursive.block(10)\n    case it {\n      0 -&gt; 1\n      _ -&gt; it * f(it - 1)\n    }\n   })\n\n   // Tail recursive factorial\n   io.debug({\n    use it, res, f &lt;- recursive.block2(10, 1)\n    case it {\n      0 -&gt; res\n      _ -&gt; f(it - 1, res * it)\n    }\n   })\n\n   // Tail recursive fibonacci\n   io.debug({\n    use it, curr, prev, f &lt;- recursive.block3(9, 1, 0)\n    case it {\n      0 -&gt; curr\n      _ -&gt; f(it - 1, curr + prev, curr)\n    }\n   })\n}\n```\n\n## Recursive anonymous function\n\n```gleam\nimport gleam/io\nimport recursive\n\npub fn main() {\n   // Factorial\n   let fac = recursive.func(fn (it, f) {\n      case it {\n        0 -&gt; 1\n        _ -&gt; it * f(it - 1)\n      }\n   })\n   io.debug(fac(10))\n\n   // Tail recursive factorial\n   let memo_fac = recursive.func(fn (it, res, f) {\n      case it {\n        0 -&gt; res\n        _ -&gt; f(it - 1, res * it)\n      }\n   })\n   io.debug(fac(10, 1))\n\n   // Tail recursive fibonacci\n   let fib = recursive.func(fn (it, curr, prev, f) {\n      case it {\n        0 -&gt; curr\n        _ -&gt; f(it - 1, curr + prev, curr)\n      }\n   })\n   io.debug(fac(9, 1, 0))\n}\n```\n\n## Development\n\n```sh\ngleam test\n```\n\n---\nFurther documentation can be found at &lt;https://hexdocs.pm/recursive&gt;.\n","url":"index.html"},{"doc":"recursive","title":"block","content":"pub fn block(initial: a, cb: fn(a, fn(a) -&gt; b) -&gt; b) -&gt; b\n Fixed-point combinator.\n Allows any block to run recursively\n \n // Factorial \n io.debug({\n   use it, f &lt;- recursive.block(10)\n   case it {\n     0 -&gt; 1\n     1 -&gt; 1\n     _ -&gt; it * f(it - 1)\n   }\n })\n \nSynonyms:\nrecursive.block\nrecursive block","url":"recursive.html#block"},{"doc":"recursive","title":"block2","content":"pub fn block2(a: a, b: b, cb: fn(a, b, fn(a, b) -&gt; c) -&gt; c) -&gt; c\n Two argument Fixed-point combinator.\n Allows any block to run recursively\n \n // Tail recursive factorial \n io.debug({\n   use it, res, f &lt;- recursive.block2(10, 1)\n   case it {\n     0 -&gt; res\n     1 -&gt; res\n     _ -&gt; f(it - 1, res * it)\n   }\n })\n \nSynonyms:\nrecursive.block2\nrecursive block2","url":"recursive.html#block2"},{"doc":"recursive","title":"block3","content":"pub fn block3(\n  a: a,\n  b: b,\n  c: c,\n  cb: fn(a, b, c, fn(a, b, c) -&gt; d) -&gt; d,\n) -&gt; d\n Three argument Fixed-point combinator.\n Allows any block to run recursively\n \n // Fibonacci \n io.debug({\n   use it, curr, prev, f &lt;- recursive.block3(9, 1, 0)\n   case it {\n    0 -&gt; curr\n    _ -&gt; f(it - 1, curr + prev, curr)\n   }\n })\n \nSynonyms:\nrecursive.block3\nrecursive block3","url":"recursive.html#block3"},{"doc":"recursive","title":"block4","content":"pub fn block4(\n  a: a,\n  b: b,\n  c: c,\n  d: d,\n  cb: fn(a, b, c, d, fn(a, b, c, d) -&gt; e) -&gt; e,\n) -&gt; e\n Four argument Fixed-point combinator.\n Allows any block to run recursively\nSynonyms:\nrecursive.block4\nrecursive block4","url":"recursive.html#block4"},{"doc":"recursive","title":"block5","content":"pub fn block5(\n  a: a,\n  b: b,\n  c: c,\n  d: d,\n  e: e,\n  cb: fn(a, b, c, d, e, fn(a, b, c, d, e) -&gt; f) -&gt; f,\n) -&gt; f\n Five argument Fixed-point combinator.\n Allows any block to run recursively\nSynonyms:\nrecursive.block5\nrecursive block5","url":"recursive.html#block5"},{"doc":"recursive","title":"func","content":"pub fn func(cb: fn(a, fn(a) -&gt; b) -&gt; b) -&gt; fn(a) -&gt; b\n Fixed-point combinator.\n Allows anonymous functions to run recursively\n \n let factorial = recursive.func(fn (it, f) {\n   case it {\n     0 -&gt; 1\n     1 -&gt; 1\n     _ -&gt; it * f(it - 1)\n   }\n })\n io.debug(factorial(10))\n \nSynonyms:\nrecursive.func\nrecursive func","url":"recursive.html#func"},{"doc":"recursive","title":"func2","content":"pub fn func2(cb: fn(a, b, fn(a, b) -&gt; c) -&gt; c) -&gt; fn(a, b) -&gt; c\n Two argument Fixed-point combinator.\n Allows anonymous functions to run recursively\n \n let factorial = recursive.func2(fn (it, res, f) {\n   case it {\n     0 -&gt; res\n     1 -&gt; res\n     _ -&gt; f(it - 1, res * it)\n   }\n })\n io.debug(factorial(10, 1))\n \nSynonyms:\nrecursive.func2\nrecursive func2","url":"recursive.html#func2"},{"doc":"recursive","title":"func3","content":"pub fn func3(\n  cb: fn(a, b, c, fn(a, b, c) -&gt; d) -&gt; d,\n) -&gt; fn(a, b, c) -&gt; d\n Three argument Fixed-point combinator.\n Allows anonymous functions to run recursively\n \n let fibonacci = recursive.func3(fn (it, curr, prev, f) {\n    case it {\n      0 -&gt; curr\n      _ -&gt; f(it - 1, curr + prev, curr)\n    }\n })\n io.debug(fibonacci(9, 1, 0))\n \nSynonyms:\nrecursive.func3\nrecursive func3","url":"recursive.html#func3"},{"doc":"recursive","title":"func4","content":"pub fn func4(\n  cb: fn(a, b, c, d, fn(a, b, c, d) -&gt; e) -&gt; e,\n) -&gt; fn(a, b, c, d) -&gt; e\n Four argument Fixed-point combinator.\n Allows anonymous functions to run recursively\nSynonyms:\nrecursive.func4\nrecursive func4","url":"recursive.html#func4"},{"doc":"recursive","title":"func5","content":"pub fn func5(\n  cb: fn(a, b, c, d, e, fn(a, b, c, d, e) -&gt; f) -&gt; f,\n) -&gt; fn(a, b, c, d, e) -&gt; f\n Five argument Fixed-point combinator.\n Allows anonymous functions to run recursively\nSynonyms:\nrecursive.func5\nrecursive func5","url":"recursive.html#func5"},{"doc":"recursive","title":"rec","content":"pub fn rec(f: fn(fn() -&gt; a) -&gt; a) -&gt; a\n Raw fixed-point combinator.\n Not intended to be used standalone\nSynonyms:\nrecursive.rec\nrecursive rec","url":"recursive.html#rec"},{"doc":"recursive","title":"recursive","content":"","url":"recursive.html"}]);